#!/usr/bin/env node

const chalk = require('chalk');
const program = require('commander');
const inquirer = require('inquirer');
const fs = require('fs-extra');
const cp = require('child_process');
const path = require('path');
const { generateFiles } = require('../utils');
const packageJson = require('../package.json');

async function createApp(projectName) {
  if (fs.pathExistsSync(projectName)) {
    const { action } = await inquirer.prompt([{
      name: 'action',
      type: 'list',
      message: `项目文件夹 ${chalk.green(projectName)} 已存在，请选择一个操作执行：`,
      choices: [
        { name: '覆盖（删除原文件）', value: 'overwrite' },
        { name: '合并（保留原文件）', value: 'merge' },
        { name: '取消', value: false },
      ],
    }]);

    if (!action) {
      return;
    } else if (action === 'overwrite') {
      await fs.remove(projectName);
    }
  }

  const { target, type } = await inquirer.prompt([
    {
      name: 'target',
      type: 'list',
      message: '请选择终端：',
      choices: [
        { name: 'pc端', value: 'pc' },
        { name: '移动端', value: 'mobile' },
        { name: '取消', value: false },
      ],
    },
    {
      name: 'type',
      type: 'list',
      message: '请选择项目类型：',
      choices: ({ target: tar }) => {
        const choices = [
          { name: 'SPA (React + React Router)', value: 'spa' },
          { name: 'SPA Pro (React + React Router + Redux)', value: 'spa-pro' },
          { name: '取消', value: false },
        ];

        if (tar === 'pc') {
          choices.unshift({ name: '曹操中心项目 (SPA Pro + Ant Design)', value: 'cc-center' });
        }

        return choices;
      },
    },
  ]);

  if (!target || !type) {
    return;
  }

  const projectPath = path.join(process.cwd(), projectName);
  fs.ensureDirSync(projectName);
  generateFiles(projectName, projectPath, target, type);

  cp.execSync('yarn', {
    cwd: projectName,
    stdio: 'inherit',
  });
}

program
  .version(packageJson.version);

program
  .command('create')
  .arguments('<project-directory>')
  .description('create a new project.')
  .action((projectName) => {
    createApp(projectName);
  });

// program
//   .command('init')
//   .description('init a new project.')
//   .action(() => {
//     const projectName = '.';
//     createApp(projectName);
//   });

program
  .arguments('<command>')
  .action((cmd) => {
    console.log();
    console.log(`  ${chalk.red(`Unknown command ${chalk.yellow(cmd)}.`)}`);
    console.log(`  Please run ${chalk.cyan('ytian -h')} for more information of usage.`);
    console.log();
  });

program.parse(process.argv);
