import React, { Component } from 'react';
import { connect } from 'react-redux';
import { Link } from 'react-router';
import { dispatch } from 'caoh5-util';
import { Form, Input, Button, Table } from 'antd';
import { loadData } from '@/actions/departments/staffs';

const FormItem = Form.Item;
const mapStateToProps = (state) => ({
  list: state.departmentsReducer.staffsReducer.list,
});
const mapDispatchToProps = {
  dispatch,
  loadData,
};
const formOption = {
  mapPropsToFields(props) {
    return {
      name: Form.createFormField(props.list.filter.name),
      depart: Form.createFormField(props.list.filter.depart),
    };
  },
  onFieldsChange(props, fields) {
    props.dispatch('STAFF_LIST_UPDATE', {
      filter: {
        ...props.list.filter,
        ...fields,
      },
    });
  },
};

@connect(mapStateToProps, mapDispatchToProps)
@Form.create(formOption)
export default class Staffs extends Component {
  constructor(props) {
    super(props);

    this.state = {
      columns: [
        {
          title: '姓名',
          dataIndex: 'name',
          width: 200,
        },
        {
          title: '部门',
          dataIndex: 'depart',
          width: 200,
        },
        {
          title: '操作',
          key: 'action',
          render: (text, record) => ([
            <Link key="edit" to={`/departments/staffs/${record.id}`}>详情</Link>,
          ]),
        },
      ],
    };
  }

  resetFilter = () => {
    this.props.dispatch('STAFF_LIST_RESET');
  }

  searchData = () => {
    this.loadData(1);
  }

  dataChange = (pagination) => {
    this.loadData(pagination.current);
  }

  loadData(current) {
    const { loadData, form } = this.props;

    const demo = {
      name: '31',
      age: 21,
    };

    Object.keys(demo).forEach((name) => {
      console.log(name);
    });


    form.validateFields((err) => {
      if (!err) {
        loadData(current);
      }
    });
  }

  componentWillMount() {
    this.loadData(1);
  }

  componentWillUnmount() {
    this.resetFilter();
  }

  render() {
    const { list, form } = this.props;
    const { getFieldDecorator } = form;

    return [
      <Form className="cc-table-filter" key="form" layout="inline">
        <FormItem label="姓名">
          {getFieldDecorator('name', {
            rules: [
              { max: 50, message: '最多输入50字' },
            ],
          })(<Input className="cc-input" />)}
        </FormItem>
        <FormItem label="部门">
          {getFieldDecorator('depart', {
            rules: [
              { max: 50, message: '最多输入50字' },
            ],
          })(<Input className="cc-input" />)}
        </FormItem>
        <FormItem>
          <Button type="primary" htmlType="submit" loading={list.isLoading} onClick={this.searchData}>查询</Button>
          <Button onClick={this.resetFilter}>重置</Button>
        </FormItem>
      </Form>,
      <div key="operation" className="cc-table-operation">
        <Button>新增</Button>
      </div>,
      <Table
        key="table"
        className="cc-table"
        size="middle"
        bordered
        dataSource={list.dataList}
        loading={list.isLoading}
        columns={this.state.columns}
        pagination={list.pagination}
        onChange={this.dataChange}
      />,
    ];
  }
}
