const path = require('path');
const fs = require('fs-extra');
const readPkg = require('read-pkg');
const writePkg = require('write-pkg');
const stringifyJS = require('javascript-stringify');

function createEmptyDirectories(directories, targetPath) {
  directories.forEach((directory) => {
    fs.ensureDirSync(`${targetPath}/${directory}`);
  });
}

exports.generateFiles = (projectName, projectPath, target, type) => {
  fs.copySync(path.join(__dirname, '../templates/common'), projectPath);
  fs.copySync(path.join(__dirname, `../templates/${type}`), projectPath);

  if (target === 'pc') {
    fs.copySync(path.join(__dirname, '../templates/pc'), `${projectName}/src`);
  }

  if (target === 'mobile') {
    fs.copySync(path.join(__dirname, '../templates/mobile'), `${projectName}/src`);
  }

  createEmptyDirectories(['assets', 'components', 'configs', 'middlewares'], `${projectName}/src`);
  createEmptyDirectories(['test'], projectName);
  fs.outputFileSync(`${projectName}/.gitignore`, ['node_modules', '.DS_Store', '*.log', 'build'].join('\n'));

  const appConfig = {
    name: projectName,
    target,
    type,
  };
  const pkg = readPkg.sync(projectPath);

  /* eslint-disable-next-line no-underscore-dangle */
  delete pkg._id;
  delete pkg.readme;
  pkg.name = projectName;

  if (type !== 'cc-center') {
    delete pkg.dependencies.antd;
  }

  // output config files.
  fs.outputFileSync(`${projectPath}/ytian.config.js`, `module.exports = ${stringifyJS(appConfig, null, 2)}`);
  writePkg.sync(projectPath, pkg);
};
